@@ -25,6 +25,28 @@
 #include <lal/LALString.h>
 #include <lal/Date.h>
 
+
+/* suppress warnings from FrameC headers; remove this when headers are fixed */
+#if ((__GNUC__ * 100) + __GNUC_MINOR__) >= 402
+#define GCC_DIAG_STR(s) #s
+#define GCC_DIAG_JOINSTR(x,y) GCC_DIAG_STR(x ## y)
+# define GCC_DIAG_DO_PRAGMA(x) _Pragma (#x)
+# define GCC_DIAG_PRAGMA(x) GCC_DIAG_DO_PRAGMA(GCC diagnostic x)
+# if ((__GNUC__ * 100) + __GNUC_MINOR__) >= 406
+#  define GCC_DIAG_OFF(x) GCC_DIAG_PRAGMA(push) \
+	GCC_DIAG_PRAGMA(ignored GCC_DIAG_JOINSTR(-W,x))
+#  define GCC_DIAG_ON(x) GCC_DIAG_PRAGMA(pop)
+# else
+#  define GCC_DIAG_OFF(x) GCC_DIAG_PRAGMA(ignored GCC_DIAG_JOINSTR(-W,x))
+#  define GCC_DIAG_ON(x)  GCC_DIAG_PRAGMA(warning GCC_DIAG_JOINSTR(-W,x))
+# endif
+#else
+# define GCC_DIAG_OFF(x)
+# define GCC_DIAG_ON(x)
+#endif
+
+GCC_DIAG_OFF(strict-prototypes)
+
 #ifdef CHAR
 #undef CHAR
 #endif
@@ -36,6 +58,8 @@
 #undef CHAR
 #define CHAR CHAR
 
+GCC_DIAG_ON(strict-prototypes)
+
 /* resolve incomplete types with FrameC structs and custom structs */
 #define tagLALFrameUFrameH		frame_h
 #define tagLALFrameUFrChan		fr_chan
