@@ -17,11 +17,14 @@
 *  MA  02111-1307  USA
 */
 
+#include <config.h>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <lal/LALStdlib.h>
 #include <lal/LALString.h>
 #include <lal/Date.h>
@@ -43,6 +46,45 @@
 #include <lal/LALFrameU.h>
 #include "LALFrameUFrameL.h"
 
+static const char * XLALFrameLErrorMessage(FRERROR frerror)
+{
+    switch (frerror) {
+    case FR_OK:
+        return "FR_OK";
+    case FR_ERROR_NO_FRAME:
+        return "FR_ERROR_NO_FRAME";
+    case FR_ERROR_NO_FILE:
+        return "FR_ERROR_NO_FILE";
+    case FR_ERROR_MALLOC_FAILED:
+        return "FR_ERROR_MALLOC_FAILED";
+    case FR_ERROR_BUFF_OVERFLOW:
+        return "FR_ERROR_BUFF_OVERFLOW";
+    case FR_ERROR_WRITE_ERROR:
+        return "FR_ERROR_WRITE_ERROR";
+    case FR_ERROR_READ_ERROR:
+        return "FR_ERROR_READ_ERROR";
+    case FR_ERROR_FRSET:
+        return "FR_ERROR_FRSET";
+    case FR_ERROR_WRONG_CHAR_LENGTH:
+        return "FR_ERROR_WRONG_CHAR_LENGTH";
+    case FR_ERROR_BAD_END_OF_FRAME:
+        return "FR_ERROR_BAD_END_OF_FRAME";
+    case FR_ERROR_OPEN_ERROR:
+        return "FR_ERROR_OPEN_ERROR";
+    case FR_ERROR_CHECKSUM:
+        return "FR_ERROR_CHECKSUM";
+    case FR_ERROR_BAD_NEVENT:
+        return "FR_ERROR_BAD_NEVENT";
+    case FR_ERROR_BAD_NSTAT:
+        return "FR_ERROR_BAD_NSTAT";
+    case FR_ERROR_TOO_LONG_STRING:
+        return "FR_ERROR_TOO_LONG_STRING";
+    default:
+        return "Unrecognized FrameL error code";
+    }
+    return "Invalid FrameL error code";
+}
+
 enum { XLAL_FRAMEU_FR_FILE_MODE_R, XLAL_FRAMEU_FR_FILE_MODE_W };
 struct tagLALFrameUFrFile {
     int mode;
@@ -138,6 +180,8 @@ LALFrameUFrFile *XLALFrameUFrFileOpen_FrameL_(const char *filename, const char *
             LALFree(stream);
             XLAL_ERROR_NULL(XLAL_EIO, "FrFileINew failed.");
         }
+        /* turn on structure checksum checking */
+        stream->handle->chkSumFrFlag = FR_YES;
         stream->mode = XLAL_FRAMEU_FR_FILE_MODE_R;
     } else {
         if (filename == NULL || strcmp(filename, "-") == 0) {
@@ -351,17 +395,17 @@ LALFrameUFrameH *XLALFrameUFrameHRead_FrameL_(LALFrameUFrFile * stream, int pos)
 
     /* make sure the TOC is read */
     if (stream->handle->toc == NULL)
-        if (FrTOCReadFull(stream->handle) == NULL)
-            XLAL_ERROR_NULL(XLAL_EIO, "FrTOCReadFull failed");
+        if (FrTOCReadFull(stream->handle) == NULL || stream->handle->error != FR_OK)
+            XLAL_ERROR_NULL(XLAL_EIO, "FrTOCReadFull failed with error code %s.", XLALFrameLErrorMessage(stream->handle->error));
 
     /* go to the right position */
     if (FrFileIOSet(stream->handle, stream->handle->toc->positionH[pos]) == -1)
-        XLAL_ERROR_NULL(XLAL_EIO, "FrFileIOSet failed");
+        XLAL_ERROR_NULL(XLAL_EIO, "FrFileIOSet failed with error code %s.", XLALFrameLErrorMessage(stream->handle->error));
 
     /* get the frame */
     frame = FrameRead(stream->handle);
-    if (!frame)
-        XLAL_ERROR_NULL(XLAL_EIO, "FrameRead failed");
+    if (!frame || stream->handle->error != FR_OK)
+        XLAL_ERROR_NULL(XLAL_EIO, "FrameRead failed with error code %s.", XLALFrameLErrorMessage(stream->handle->error));
 
     copy = FrameHCopy(frame);
     FrSetIni(stream->handle);
@@ -374,7 +418,7 @@ LALFrameUFrameH *XLALFrameUFrameHRead_FrameL_(LALFrameUFrFile * stream, int pos)
 int XLALFrameUFrameHWrite_FrameL_(LALFrameUFrFile * stream, LALFrameUFrameH * frame)
 {
     if (FrameWrite(frame, stream->handle) != FR_OK)
-        XLAL_ERROR(XLAL_EIO, "FrameWrite failed");
+        XLAL_ERROR(XLAL_EIO, "FrameWrite failed with error code %s.", XLALFrameLErrorMessage(stream->handle->error));
     return 0;
 }
 
@@ -641,8 +685,7 @@ int XLALFrameUFrameHFrDetectorAdd_FrameL_(LALFrameUFrameH * frame, LALFrameUFrDe
             XLAL_ERROR(XLAL_ENOMEM);
         }
     }
-    if (detector->handle->prefix)
-        memcpy(copy->prefix, detector->handle->prefix, 2);
+    memcpy(copy->prefix, detector->handle->prefix, 2);
 
     copy->longitude = detector->handle->longitude;
     copy->latitude = detector->handle->latitude;
@@ -666,7 +709,7 @@ int XLALFrameUFrameHFrHistoryAdd_FrameL_(LALFrameUFrameH * frame, LALFrameUFrHis
     FrHistory *copy;
     copy = FrHistoryNew(history->name ? history->name : frame->name, history->time, history->comment);
     if (!copy)
-        XLAL_ERROR(XLAL_EIO, "FrHistoryNew failed");
+        XLAL_ERROR(XLAL_EIO, "FrHistoryNew failed.");
     copy->next = frame->history;
     frame->history = copy;
     return 0;
@@ -753,10 +796,10 @@ LALFrameUFrChan *XLALFrameUFrChanRead_FrameL_(LALFrameUFrFile * stream, const ch
     toc = stream->handle->toc;
     if (!toc)
         toc = FrTOCReadFull(stream->handle);
-    if (!toc)
-        XLAL_ERROR_NULL(XLAL_EIO, "FrTOCReadFull failed");
+    if (!toc || stream->handle->error != FR_OK)
+        XLAL_ERROR_NULL(XLAL_EIO, "FrTOCReadFull failed with error code %s.", XLALFrameLErrorMessage(stream->handle->error));
     if (pos >= (size_t) toc->nFrame)
-        XLAL_ERROR_NULL(XLAL_EINVAL, "pos = %zu out of range");
+      XLAL_ERROR_NULL(XLAL_EINVAL, "pos = %zu out of range", pos);
 
     /* the gps time of the frame at position pos */
     gtime = toc->GTimeS[pos] + 1e-9 * toc->GTimeN[pos];
@@ -779,6 +822,8 @@ LALFrameUFrChan *XLALFrameUFrChanRead_FrameL_(LALFrameUFrFile * stream, const ch
             gtime += adc->timeOffset;
             //adc->next = NULL;
             adc->data = FrVectReadNext(stream->handle, gtime, adc->name);
+            if (stream->handle->error != FR_OK)
+                goto failure;
             channel->handle.adc = adc;
             channel->type = XLAL_FRAMEU_FR_CHAN_TYPE_ADC;
             return channel;
@@ -796,6 +841,8 @@ LALFrameUFrChan *XLALFrameUFrChanRead_FrameL_(LALFrameUFrFile * stream, const ch
             gtime += proc->timeOffset;
             proc->next = NULL;
             proc->data = FrVectReadNext(stream->handle, gtime, proc->name);
+            if (stream->handle->error != FR_OK)
+                goto failure;
             channel->handle.proc = proc;
             channel->type = XLAL_FRAMEU_FR_CHAN_TYPE_PROC;
             return channel;
@@ -813,6 +860,8 @@ LALFrameUFrChan *XLALFrameUFrChanRead_FrameL_(LALFrameUFrFile * stream, const ch
             gtime += sim->timeOffset;
             sim->next = NULL;
             sim->data = FrVectReadNext(stream->handle, gtime, sim->name);
+            if (stream->handle->error != FR_OK)
+                goto failure;
             channel->handle.sim = sim;
             channel->type = XLAL_FRAMEU_FR_CHAN_TYPE_SIM;
             return channel;
@@ -821,7 +870,10 @@ LALFrameUFrChan *XLALFrameUFrChanRead_FrameL_(LALFrameUFrFile * stream, const ch
     /* couldn't find channel */
   failure:
     LALFree(channel);
-    XLAL_ERROR_NULL(XLAL_ENAME, "Channel %s not found", name);
+    if (stream->handle->error == FR_OK)
+        XLAL_ERROR_NULL(XLAL_ENAME, "Channel %s not found", name);
+    else
+        XLAL_ERROR_NULL(XLAL_EIO, "Channel %s could not be read: error code %s", name, XLALFrameLErrorMessage(stream->handle->error));
 }
 
 /* stripped-down copy of FrAdcDataNewF */
