@@ -22,9 +22,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <getopt.h>
 
 #include <lal/Date.h>
+#include <lal/LALgetopt.h>
 #include <lal/LALStdlib.h>
 #include <lal/TimeSeries.h>
 #include <lal/LALFrStream.h>
@@ -144,7 +144,7 @@ int main(int argc, char *argv[])
 
 int parseargs(int argc, char **argv)
 {
-    struct option long_options[] = {
+    struct LALoption long_options[] = {
         {"help", no_argument, 0, 'h'},
         {"channel", required_argument, 0, 'c'},
         {"frame-cache", required_argument, 0, 'f'},
@@ -158,7 +158,7 @@ int parseargs(int argc, char **argv)
         int option_index = 0;
         int c;
 
-        c = getopt_long_only(argc, argv, args, long_options, &option_index);
+        c = LALgetopt_long_only(argc, argv, args, long_options, &option_index);
         if (c == -1)    /* end of options */
             break;
 
@@ -168,26 +168,26 @@ int parseargs(int argc, char **argv)
                 break;
             else {
                 fprintf(stderr, "error parsing option %s with argument %s\n",
-                    long_options[option_index].name, optarg);
+                    long_options[option_index].name, LALoptarg);
                 exit(1);
             }
         case 'h':      /* help */
             usage(argv[0]);
             exit(0);
         case 'c':      /* channel */
-            channel = strdup(optarg);
+            channel = strdup(LALoptarg);
             break;
         case 'f':      /* frame-cache */
-            cache = XLALCacheImport(optarg);
+            cache = XLALCacheImport(LALoptarg);
             break;
         case 'g':      /* frame-cache */
-            cache = XLALCacheGlob(NULL, optarg);
+            cache = XLALCacheGlob(NULL, LALoptarg);
             break;
         case 's':      /* start-time */
-            t0 = atof(optarg);
+            t0 = atof(LALoptarg);
             break;
         case 't':      /* duration */
-            dt = atof(optarg);
+            dt = atof(LALoptarg);
             break;
         case '?':
         default:
@@ -196,10 +196,10 @@ int parseargs(int argc, char **argv)
         }
     }
 
-    if (optind < argc) {
+    if (LALoptind < argc) {
         fprintf(stderr, "extraneous command line arguments:\n");
-        while (optind < argc)
-            fprintf(stderr, "%s\n", argv[optind++]);
+        while (LALoptind < argc)
+            fprintf(stderr, "%s\n", argv[LALoptind++]);
         exit(1);
     }
 
